@@ -9,8 +9,10 @@ if os.path.isdir(DIR):
     sys.path.insert(0, os.path.dirname(DIR))
 
 import unittest
+import doctest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import test_view
+from trytond.tests.test_tryton import test_view, test_depends
+from trytond.backend.sqlite.database import Database as SQLiteDatabase
 
 
 class AccountStatementTestCase(unittest.TestCase):
@@ -25,12 +27,33 @@ class AccountStatementTestCase(unittest.TestCase):
         '''
         Test views.
         '''
-        self.assertRaises(Exception, test_view('account_statement'))
+        test_view('account_statement')
+
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
+
+def doctest_dropdb(test):
+    '''
+    Remove sqlite memory database
+    '''
+    database = SQLiteDatabase().connect()
+    cursor = database.cursor(autocommit=True)
+    try:
+        database.drop(cursor, ':memory:')
+        cursor.commit()
+    finally:
+        cursor.close()
 
 def suite():
     suite = trytond.tests.test_tryton.suite()
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
         AccountStatementTestCase))
+    suite.addTests(doctest.DocFileSuite('scenario_account_statement.rst',
+        setUp=doctest_dropdb, tearDown=doctest_dropdb, encoding='utf-8',
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
 
 if __name__ == '__main__':
